# -*- coding: utf-8 -*-
# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


class User(object):
    def __init__(self, id, team_id, first_name, last_name, email, note, start_date):
        self.id = id
        self.team_id = team_id
        self.first_name = first_name
        self.last_name = last_name
        self.email = email
        self.note = note
        self.start_date = start_date

    def __str__(self):
        return "User '{0} {1}' {2} ({3})".format(
            self.first_name, self.last_name, self.email, self.id
        )
